@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,21 +12,21 @@
 
 #include "pimcommon_debug.h"
 
-#include <QPointer>
-#include <QVBoxLayout>
-#include <QPushButton>
-#include <QKeyEvent>
-#include <QToolBar>
 #include <QAction>
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QDialogButtonBox>
+#include <QKeyEvent>
+#include <QPointer>
+#include <QPushButton>
+#include <QToolBar>
+#include <QVBoxLayout>
 
 ConfigureTestDialog::ConfigureTestDialog(PimCommon::AutoCorrection *autoCorrection, QWidget *parent)
     : QDialog(parent)
 {
     setWindowTitle(QStringLiteral("Configure Autocorrection"));
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
@@ -92,11 +92,11 @@ AutocorrectionTestWidget::AutocorrectionTestWidget(QWidget *parent)
     PimCommon::PimCommonSettings::self()->load();
 
     mAutoCorrection = new PimCommon::AutoCorrection;
-    auto *lay = new QVBoxLayout(this);
-    auto *bar = new QToolBar;
+    auto lay = new QVBoxLayout(this);
+    auto bar = new QToolBar;
     lay->addWidget(bar);
     bar->addAction(QStringLiteral("Configure..."), this, &AutocorrectionTestWidget::slotConfigure);
-    QAction *richText = new QAction(QStringLiteral("HTML mode"), this);
+    auto richText = new QAction(QStringLiteral("HTML mode"), this);
     richText->setCheckable(true);
     connect(richText, &QAction::toggled, this, &AutocorrectionTestWidget::slotChangeMode);
     bar->addAction(richText);
@@ -138,7 +138,7 @@ int main(int argc, char **argv)
     parser.addHelpOption();
     parser.process(app);
 
-    auto *w = new AutocorrectionTestWidget();
+    auto w = new AutocorrectionTestWidget();
     w->resize(800, 600);
 
     w->show();
