@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -31,7 +31,7 @@ CustomToolsWidgetNg::CustomToolsWidgetNg(QWidget *parent)
     : QWidget(parent)
     , d(new PimCommon::CustomToolsWidgetNgPrivate)
 {
-    auto *lay = new QHBoxLayout(this);
+    auto lay = new QHBoxLayout(this);
     d->mStackedWidget = new QStackedWidget;
     d->mStackedWidget->setObjectName(QStringLiteral("stackedwidget"));
     lay->addWidget(d->mStackedWidget);
