@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef TEMPLATELISTWIDGET_H
@@ -22,7 +10,8 @@
 #include "pimcommon_export.h"
 #include <QListWidget>
 
-namespace PimCommon {
+namespace PimCommon
+{
 class TemplateListWidgetPrivate;
 
 struct defaultTemplate {
@@ -41,7 +30,7 @@ public:
     explicit TemplateListWidget(const QString &configName, QWidget *parent = nullptr);
     ~TemplateListWidget() override;
 
-    //Need to load template in specific class to allow to use correct defaultTemplates function
+    // Need to load template in specific class to allow to use correct defaultTemplates function
     void loadTemplates();
 
     Q_REQUIRED_RESULT virtual QVector<PimCommon::defaultTemplate> defaultTemplates();
@@ -57,10 +46,7 @@ protected:
     QMimeData *mimeData(const QList<QListWidgetItem *> items) const override;
 
     void dropEvent(QDropEvent *event) override;
-    enum TemplateData {
-        Text = Qt::UserRole + 1,
-        DefaultTemplate = Qt::UserRole + 2
-    };
+    enum TemplateData { Text = Qt::UserRole + 1, DefaultTemplate = Qt::UserRole + 2 };
 
 Q_SIGNALS:
     void insertTemplate(const QString &);
