@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,7 +14,7 @@ class LineEditWithCompleterNgTest : public QObject
     Q_OBJECT
 public:
     explicit LineEditWithCompleterNgTest(QObject *parent = nullptr);
-    ~LineEditWithCompleterNgTest() = default;
+    ~LineEditWithCompleterNgTest() override = default;
 
 private Q_SLOTS:
     void shouldHaveDefaultValue();
