@@ -1,23 +1,23 @@
 /*
- * SPDX-FileCopyrightText: 2011-2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
 #include "renamefiledialog.h"
-#include <kseparator.h>
-#include <QLineEdit>
-#include <QPushButton>
-#include <KLocalizedString>
 #include <KIO/StatJob>
 #include <KJobWidgets>
+#include <KLocalizedString>
 #include <KMessageBox>
 #include <KStandardGuiItem>
+#include <QLineEdit>
+#include <QPushButton>
+#include <kseparator.h>
 
-#include <QHBoxLayout>
 #include <QCheckBox>
+#include <QFileInfo>
+#include <QHBoxLayout>
 #include <QLabel>
 #include <QVBoxLayout>
-#include <QFileInfo>
 
 using namespace PimCommon;
 
@@ -46,7 +46,7 @@ QString PimCommon::RenameFileDialog::RenameFileDialogPrivate::suggestName(const
     QString basename = oldName;
     const QChar spacer(QLatin1Char(' '));
 
-    //ignore dots at the beginning, that way "..aFile.tar.gz" will become "..aFile 1.tar.gz" instead of " 1..aFile.tar.gz"
+    // ignore dots at the beginning, that way "..aFile.tar.gz" will become "..aFile 1.tar.gz" instead of " 1..aFile.tar.gz"
     int index = basename.indexOf(QLatin1Char('.'));
     int continuous = 0;
     while (continuous == index) {
@@ -66,7 +66,7 @@ QString PimCommon::RenameFileDialog::RenameFileDialogPrivate::suggestName(const
         bool ok;
         const int number = tmp.toInt(&ok);
 
-        if (!ok) {  // ok there is no number
+        if (!ok) { // ok there is no number
             suggestedName = basename + spacer + QLatin1Char('1') + dotSuffix;
         } else {
             // yes there's already a number behind the spacer so increment it by one
@@ -97,12 +97,12 @@ RenameFileDialog::RenameFileDialog(const QUrl &url, bool multiFiles, QWidget *pa
     , d(new RenameFileDialogPrivate(url, this))
 {
     setWindowTitle(i18nc("@title:window", "File Already Exists"));
-    auto *pLayout = new QVBoxLayout(this);
+    auto pLayout = new QVBoxLayout(this);
 
-    QLabel *label = new QLabel(xi18n("A file named <filename>%1</filename> already exists. Do you want to overwrite it?", url.fileName()), this);
+    auto label = new QLabel(xi18n("A file named <filename>%1</filename> already exists. Do you want to overwrite it?", url.fileName()), this);
     pLayout->addWidget(label);
 
-    auto *renameLayout = new QHBoxLayout();
+    auto renameLayout = new QHBoxLayout();
     pLayout->addLayout(renameLayout);
 
     d->nameEdit = new QLineEdit(this);
@@ -113,20 +113,20 @@ RenameFileDialog::RenameFileDialog(const QUrl &url, bool multiFiles, QWidget *pa
     renameLayout->addWidget(d->suggestNewNameBtn);
     connect(d->suggestNewNameBtn, &QPushButton::clicked, this, &RenameFileDialog::slotSuggestNewNamePressed);
 
-    auto *overWrite = new QPushButton(this);
+    auto overWrite = new QPushButton(this);
     KStandardGuiItem::assign(overWrite, KStandardGuiItem::Overwrite);
     connect(overWrite, &QPushButton::clicked, this, &RenameFileDialog::slotOverwritePressed);
 
-    QPushButton *ignore = new QPushButton(i18n("&Ignore"), this);
+    auto ignore = new QPushButton(i18n("&Ignore"), this);
     connect(ignore, &QPushButton::clicked, this, &RenameFileDialog::slotIgnorePressed);
 
     d->renameBtn = new QPushButton(i18n("&Rename"), this);
     connect(d->renameBtn, &QPushButton::clicked, this, &RenameFileDialog::slotRenamePressed);
 
-    KSeparator *separator = new KSeparator(this);
+    auto separator = new KSeparator(this);
     pLayout->addWidget(separator);
 
-    auto *layout = new QHBoxLayout();
+    auto layout = new QHBoxLayout();
     pLayout->addLayout(layout);
 
     if (multiFiles) {
