@@ -1,35 +1,37 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef ADDRESSEELINEEDIT_P_H
 #define ADDRESSEELINEEDIT_P_H
-#include <QStringList>
-#include <QObject>
-#include <QList>
 #include <KLDAP/LdapClientSearch>
+#include <QList>
+#include <QObject>
+#include <QStringList>
 
-#include <AkonadiCore/Item>
 #include <AkonadiCore/Collection>
+#include <AkonadiCore/Item>
 #include <kcontacts/contactgroup.h>
 
 class KConfig;
 class QToolButton;
 class QTimer;
-namespace Akonadi {
+namespace Akonadi
+{
 class ContactGroupSearchJob;
 }
 
-namespace PimCommon {
+namespace PimCommon
+{
 class AddresseeLineEdit;
 class AddresseeLineEditPrivate : public QObject
 {
     Q_OBJECT
 public:
     AddresseeLineEditPrivate(AddresseeLineEdit *qq, bool enableCompletion);
-    ~AddresseeLineEditPrivate();
+    ~AddresseeLineEditPrivate() override;
     void init();
     void setCompletedItems(const QStringList &items, bool autoSuggest);
     void addCompletionItem(const QString &string, int weight, int source, const QStringList *keyWords = nullptr);
@@ -133,7 +135,7 @@ private:
     bool mCompletionInitialized = false;
     bool mSmartPaste = false;
     bool mLastSearchMode = false;
-    bool mSearchExtended = false; //has \" been added?
+    bool mSearchExtended = false; // has \" been added?
     bool mUseSemicolonAsSeparator = false;
     bool mEnableBalooSearch = true;
     bool mEnableAkonadiSearch = true;
