@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,10 +7,11 @@
 #ifndef ADDRESSEELINEEDITUTIL_H
 #define ADDRESSEELINEEDITUTIL_H
 
-#include <QString>
 #include "pimcommonakonadi_export.h"
+#include <QString>
 
-namespace PimCommon {
+namespace PimCommon
+{
 /**
  * @brief The AddresseeLineEditUtil class
  * @author Laurent Montel <montel@kde.org>
