@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -11,7 +11,8 @@
 #include <QByteArray>
 #include <QString>
 
-namespace PimCommon {
+namespace PimCommon
+{
 /**
  * @brief The CollectionTypeUtil class
  * @author Laurent Montel <montel@kde.org>
@@ -39,11 +40,7 @@ public:
         ContentsTypeLast = ContentsTypeFile
     };
 
-    enum IncidencesFor {
-        IncForNobody,
-        IncForAdmins,
-        IncForReaders
-    };
+    enum IncidencesFor { IncForNobody, IncForAdmins, IncForReaders };
 
     Q_REQUIRED_RESULT CollectionTypeUtil::IncidencesFor incidencesForFromString(const QString &string);
     Q_REQUIRED_RESULT CollectionTypeUtil::FolderContentsType typeFromKolabName(const QByteArray &name);
