@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,8 +12,8 @@
 
 #include <KCheckableProxyModel>
 
-#include <QVBoxLayout>
 #include <QTreeView>
+#include <QVBoxLayout>
 
 using namespace PimCommon;
 SelectMultiCollectionWidget::SelectMultiCollectionWidget(const QString &mimetype, QWidget *parent)
@@ -35,7 +35,7 @@ SelectMultiCollectionWidget::~SelectMultiCollectionWidget()
 
 void SelectMultiCollectionWidget::initialize(const QString &mimetype)
 {
-    auto *vbox = new QVBoxLayout(this);
+    auto vbox = new QVBoxLayout(this);
     vbox->setContentsMargins(0, 0, 0, 0);
 
     mCheckedCollectionWidget = new PimCommon::CheckedCollectionWidget(mimetype);
@@ -43,7 +43,10 @@ void SelectMultiCollectionWidget::initialize(const QString &mimetype)
     connect(mCheckedCollectionWidget, &PimCommon::CheckedCollectionWidget::collectionAdded, this, &SelectMultiCollectionWidget::slotCollectionsTreeFetched);
     connect(mCheckedCollectionWidget, &PimCommon::CheckedCollectionWidget::collectionRemoved, this, &SelectMultiCollectionWidget::slotCollectionsTreeFetched);
 
-    connect(mCheckedCollectionWidget->entityTreeModel(), &Akonadi::EntityTreeModel::collectionTreeFetched, this, &SelectMultiCollectionWidget::slotCollectionsTreeFetched);
+    connect(mCheckedCollectionWidget->entityTreeModel(),
+            &Akonadi::EntityTreeModel::collectionTreeFetched,
+            this,
+            &SelectMultiCollectionWidget::slotCollectionsTreeFetched);
     vbox->addWidget(mCheckedCollectionWidget);
 }
 
@@ -53,8 +56,8 @@ void SelectMultiCollectionWidget::updateStatus(const QModelIndex &parent)
     for (int i = 0; i < nbCol; ++i) {
         const QModelIndex child = mCheckedCollectionWidget->checkableProxy()->index(i, 0, parent);
 
-        const Akonadi::Collection col
-            = mCheckedCollectionWidget->checkableProxy()->data(child, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+        const Akonadi::Collection col =
+            mCheckedCollectionWidget->checkableProxy()->data(child, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
 
         if (mListCollection.contains(col.id())) {
             mCheckedCollectionWidget->checkableProxy()->setData(child, Qt::Checked, Qt::CheckStateRole);
@@ -79,8 +82,8 @@ QVector<Akonadi::Collection> SelectMultiCollectionWidget::selectedCollection(con
     for (int i = 0; i < nbCol; ++i) {
         const QModelIndex child = mCheckedCollectionWidget->checkableProxy()->index(i, 0, parent);
 
-        const Akonadi::Collection col
-            = mCheckedCollectionWidget->checkableProxy()->data(child, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+        const Akonadi::Collection col =
+            mCheckedCollectionWidget->checkableProxy()->data(child, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
 
         if (mCheckedCollectionWidget->checkableProxy()->data(child, Qt::CheckStateRole).value<int>()) {
             lst << col;
