@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,11 +7,12 @@
 #ifndef SELECTMULTICOLLECTIONWIDGET_H
 #define SELECTMULTICOLLECTIONWIDGET_H
 
-#include <QWidget>
 #include <Collection>
 #include <QModelIndex>
+#include <QWidget>
 
-namespace PimCommon {
+namespace PimCommon
+{
 class CheckedCollectionWidget;
 class SelectMultiCollectionWidget : public QWidget
 {
@@ -19,7 +20,7 @@ class SelectMultiCollectionWidget : public QWidget
 public:
     explicit SelectMultiCollectionWidget(const QString &mimetype, const QList<Akonadi::Collection::Id> &selectedCollection, QWidget *parent = nullptr);
     explicit SelectMultiCollectionWidget(const QString &mimetype, QWidget *parent = nullptr);
-    ~SelectMultiCollectionWidget();
+    ~SelectMultiCollectionWidget() override;
 
     Q_REQUIRED_RESULT QVector<Akonadi::Collection> selectedCollection(const QModelIndex &parent = QModelIndex()) const;
 
