@@ -1,25 +1,13 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "plugininterface.h"
 
-#include <PimCommon/GenericPluginManager>
 #include "pimcommonakonadi_debug.h"
+#include <PimCommon/GenericPluginManager>
 
 #include <KActionCollection>
 #include <KXMLGUIClient>
@@ -86,11 +74,12 @@ void PluginInterface::createPluginInterface()
         qCWarning(PIMCOMMONAKONADI_LOG) << "Missing action collection";
         return;
     }
-    for (PimCommon::GenericPlugin *plugin : d->mGenericPluginManager->pluginsList()) {
+    const auto pluginsList = d->mGenericPluginManager->pluginsList();
+    for (PimCommon::GenericPlugin *plugin : pluginsList) {
         if (plugin->isEnabled()) {
-            PimCommon::GenericPluginInterface *interface = static_cast<PimCommon::GenericPluginInterface *>(plugin->createInterface(this));
+            auto interface = static_cast<PimCommon::GenericPluginInterface *>(plugin->createInterface(this));
             interface->setParentWidget(d->mParentWidget);
-            //Add parent before creating action
+            // Add parent before creating action
             interface->createAction(d->mActionCollection);
             interface->setPlugin(plugin);
             connect(interface, &PimCommon::GenericPluginInterface::emitPluginActivated, this, &PluginInterface::slotPluginActivated);
@@ -143,7 +132,7 @@ void PluginInterface::setParentWidget(QWidget *widget)
 void PluginInterface::clearPluginActions(const QString &prefix, KXMLGUIClient *guiClient)
 {
     if (guiClient->factory()) {
-        QHashIterator<PimCommon::ActionType::Type, QList<QAction *> > localActionsType(actionsType());
+        QHashIterator<PimCommon::ActionType::Type, QList<QAction *>> localActionsType(actionsType());
         while (localActionsType.hasNext()) {
             localActionsType.next();
             QList<QAction *> lst = localActionsType.value();
@@ -158,7 +147,7 @@ void PluginInterface::clearPluginActions(const QString &prefix, KXMLGUIClient *g
 void PluginInterface::initializePluginActions(const QString &prefix, KXMLGUIClient *guiClient)
 {
     if (guiClient->factory()) {
-        QHashIterator<PimCommon::ActionType::Type, QList<QAction *> > localActionsType(actionsType());
+        QHashIterator<PimCommon::ActionType::Type, QList<QAction *>> localActionsType(actionsType());
         while (localActionsType.hasNext()) {
             localActionsType.next();
             QList<QAction *> lst = localActionsType.value();
@@ -178,15 +167,16 @@ void PluginInterface::updateActions(int numberOfSelectedItems, int numberOfSelec
     }
 }
 
-QHash<PimCommon::ActionType::Type, QList<QAction *> > PluginInterface::actionsType()
+QHash<PimCommon::ActionType::Type, QList<QAction *>> PluginInterface::actionsType()
 {
-    QHash<PimCommon::ActionType::Type, QList<QAction *> > listType;
+    QHash<PimCommon::ActionType::Type, QList<QAction *>> listType;
     for (PimCommon::GenericPluginInterface *interface : qAsConst(d->mListGenericInterface)) {
-        for (const PimCommon::ActionType &actionType : interface->actionTypes()) {
+        const auto actionTypes = interface->actionTypes();
+        for (const PimCommon::ActionType &actionType : actionTypes) {
             PimCommon::ActionType::Type type = actionType.type();
             QList<QAction *> lst = listType.value(type);
             if (!lst.isEmpty()) {
-                QAction *act = new QAction(this);
+                auto act = new QAction(this);
                 act->setSeparator(true);
                 lst << act << actionType.action();
                 listType.insert(type, lst);
@@ -197,7 +187,7 @@ QHash<PimCommon::ActionType::Type, QList<QAction *> > PluginInterface::actionsTy
                 type = PimCommon::ActionType::PopupMenu;
                 lst = listType.value(type);
                 if (!lst.isEmpty()) {
-                    QAction *act = new QAction(this);
+                    auto act = new QAction(this);
                     act->setSeparator(true);
                     lst << act << actionType.action();
                     listType.insert(type, lst);
@@ -209,7 +199,7 @@ QHash<PimCommon::ActionType::Type, QList<QAction *> > PluginInterface::actionsTy
                 type = PimCommon::ActionType::ToolBar;
                 lst = listType.value(type);
                 if (!lst.isEmpty()) {
-                    QAction *act = new QAction(this);
+                    auto act = new QAction(this);
                     act->setSeparator(true);
                     lst << act << actionType.action();
                     listType.insert(type, lst);
