@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -39,17 +39,14 @@ void ImapResourceCapabilitiesManager::slotInstanceRemoved(const Akonadi::AgentIn
 
 void ImapResourceCapabilitiesManager::searchCapabilities(const QString &identifier)
 {
-    //By default makes it as true.
+    // By default makes it as true.
     mImapResource.insert(identifier, true);
-    const QString service
-        = Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Resource, identifier);
-    QDBusInterface iface(service,
-                         QStringLiteral("/"), QStringLiteral("org.kde.Akonadi.ImapResourceBase"),
-                         QDBusConnection::sessionBus(), this);
+    const QString service = Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Resource, identifier);
+    QDBusInterface iface(service, QStringLiteral("/"), QStringLiteral("org.kde.Akonadi.ImapResourceBase"), QDBusConnection::sessionBus(), this);
 
     if (iface.isValid()) {
         QDBusPendingCall call = iface.asyncCall(QStringLiteral("serverCapabilities"));
-        auto *watcher = new QDBusPendingCallWatcher(call, this);
+        auto watcher = new QDBusPendingCallWatcher(call, this);
         watcher->setProperty("identifier", identifier);
         connect(watcher, &QDBusPendingCallWatcher::finished, this, &ImapResourceCapabilitiesManager::slotCapabilities);
     } else {
